onSubmitSearch property
Optional callback function invoked when the user submits the search
Implementation
final Function(String)? onSubmitSearch;
Optional callback function invoked when the user submits the search
final Function(String)? onSubmitSearch;