secondaryWidget property
Optional widget to display next to the search field (e.g., filter button)
Implementation
final Widget? secondaryWidget;
Optional widget to display next to the search field (e.g., filter button)
final Widget? secondaryWidget;